Crate kcr_networking_karmada_io

Crate kcr_networking_karmada_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the networking.karmada.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

networking.karmada.io/v1alpha1

  • MultiClusterIngress
  • MultiClusterService

Modules

v1alpha1